/**
 * Retrieve an URL synchronously. Note that this is synchronous, that is, it
 * will block (stall the browser!) until it's done downloading the entire
 * document.
 */
function getURL(url, username, password, asXML)
{
    const request = new XMLHttpRequest();
    
    // Retrieve page
    request.open("GET", url, false);
    // Basic authentication should be used
    if(username.length > 0)
    {
        var text = username + ":" + password;
        text = encodeBase64(text);
        request.setRequestHeader("Authorization", "Basic " + text);
    }
    request.send(null);
    
    if (request.readyState == 4 && request.status == 200)
    {
    	if(asXML) return request.responseXML;    	
    	else return request.responseText;
    }
    else throw("Unable to get URL '" + url + "' status code " + request.status);
}

/**
 * Retrieve an URL asynchronously.
 * The callback function given as a parameter will be called when the URL has been
 * loaded successfully.
 */
function asyncGetURL(url, username, password, asXML, callback)
{
    request=new XMLHttpRequest();
    // Open an asynchronous request
    request.open("GET", url, true, username, password);
    request.onreadystatechange = function() {
        // 4 is the "completed" state
        if(request.readyState==4) {
            // 200 is HTTP "OK"
            cookies.restoreCookieState();
            if(request.status==200) {
    	        if(asXML) {
    	            callback(request.responseXML);
    	        } else {
    	            callback(request.responseText);
    	        }
            } else {
                throw("HTTP status "+request.statusText+"("+request.status+").");
            }
        }
    };
    cookies.turnCookiesOn();
    request.send(null);
}
